Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorddunne2009-10-10 21:00:58 +0000
committerddunne2009-10-10 21:00:58 +0000
commit14ba8cfdb7e52a0aee2e34a1816f91f8d419034a (patch)
tree0093a8670dfc72a9a6706facc0754ff5521b1faa
parentf5e0b96da754b2d6f5120c117dc1ab77758650ce (diff)
downloadorg.eclipse.osee-14ba8cfdb7e52a0aee2e34a1816f91f8d419034a.tar.gz
org.eclipse.osee-14ba8cfdb7e52a0aee2e34a1816f91f8d419034a.tar.xz
org.eclipse.osee-14ba8cfdb7e52a0aee2e34a1816f91f8d419034a.zip
Rename attribute ats.Man Days Needed
-rw-r--r--org.eclipse.osee.ats/src/org/eclipse/osee/ats/artifact/ATSAttributes.java2
-rw-r--r--org.eclipse.osee.ats/src/org/eclipse/osee/ats/artifact/StateMachineArtifact.java4
-rw-r--r--org.eclipse.osee.ats/src/org/eclipse/osee/ats/artifact/TeamDefinitionArtifact.java18
-rw-r--r--org.eclipse.osee.ats/src/org/eclipse/osee/ats/task/TaskEditor.java2
-rw-r--r--org.eclipse.osee.ats/src/org/eclipse/osee/ats/world/AtsMetricsComposite.java2
-rw-r--r--org.eclipse.osee.ats/src/org/eclipse/osee/ats/world/WorldComposite.java2
-rw-r--r--org.eclipse.osee.ats/src/org/eclipse/osee/ats/world/WorldLabelProvider.java2
-rw-r--r--org.eclipse.osee.ats/src/org/eclipse/osee/ats/world/WorldXViewer.java5
-rw-r--r--org.eclipse.osee.ats/src/org/eclipse/osee/ats/world/WorldXViewerFactory.java6
-rw-r--r--org.eclipse.osee.ats/support/OseeTypes_ATS.osee28
10 files changed, 37 insertions, 34 deletions
diff --git a/org.eclipse.osee.ats/src/org/eclipse/osee/ats/artifact/ATSAttributes.java b/org.eclipse.osee.ats/src/org/eclipse/osee/ats/artifact/ATSAttributes.java
index bc7b133b056..68ea57bd7d2 100644
--- a/org.eclipse.osee.ats/src/org/eclipse/osee/ats/artifact/ATSAttributes.java
+++ b/org.eclipse.osee.ats/src/org/eclipse/osee/ats/artifact/ATSAttributes.java
@@ -128,7 +128,7 @@ public class ATSAttributes {
new ATSAttributes("Estimated Completion Date", "Date the changes will be completed.");
public static final ATSAttributes RELEASE_DATE_ATTRIBUTE =
new ATSAttributes("Release Date", "Date the changes were made available to the users.");
- public static final ATSAttributes MAN_DAYS_NEEDED_ATTRIBUTE = new ATSAttributes("Man Days Needed");
+ public static final ATSAttributes HOURS_PER_WORK_DAY_ATTRIBUTE = new ATSAttributes("Hours Per Work Day");
protected ATSAttributes(String displayName, String storeName, String description) {
this.displayName = displayName;
diff --git a/org.eclipse.osee.ats/src/org/eclipse/osee/ats/artifact/StateMachineArtifact.java b/org.eclipse.osee.ats/src/org/eclipse/osee/ats/artifact/StateMachineArtifact.java
index c3a33c3aa5f..855643bb144 100644
--- a/org.eclipse.osee.ats/src/org/eclipse/osee/ats/artifact/StateMachineArtifact.java
+++ b/org.eclipse.osee.ats/src/org/eclipse/osee/ats/artifact/StateMachineArtifact.java
@@ -72,7 +72,7 @@ public abstract class StateMachineArtifact extends ATSArtifact implements IGroup
private final Set<IRelationEnumeration> atsWorldRelations = new HashSet<IRelationEnumeration>();
private Collection<User> preSaveStateAssignees;
private User preSaveOriginator;
- public static double DEFAULT_MAN_HOURS_PER_DAY = 8;
+ public static double DEFAULT_HOURS_PER_WORK_DAY = 8;
protected WorkFlowDefinition workFlowDefinition;
/**
@@ -654,7 +654,7 @@ public abstract class StateMachineArtifact extends ATSArtifact implements IGroup
}
public double getManHrsPerDayPreference() throws OseeCoreException {
- return DEFAULT_MAN_HOURS_PER_DAY;
+ return DEFAULT_HOURS_PER_WORK_DAY;
}
public double getWorldViewAnnualCostAvoidance() throws OseeCoreException {
diff --git a/org.eclipse.osee.ats/src/org/eclipse/osee/ats/task/TaskEditor.java b/org.eclipse.osee.ats/src/org/eclipse/osee/ats/task/TaskEditor.java
index 08b81166c33..8d7464fce22 100644
--- a/org.eclipse.osee.ats/src/org/eclipse/osee/ats/task/TaskEditor.java
+++ b/org.eclipse.osee.ats/src/org/eclipse/osee/ats/task/TaskEditor.java
@@ -344,7 +344,7 @@ public class TaskEditor extends AbstractArtifactEditor implements IDirtiableEdit
@Override
public double getManHoursPerDayPreference() throws OseeCoreException {
- if (tasks.size() == 0) return StateMachineArtifact.DEFAULT_MAN_HOURS_PER_DAY;
+ if (tasks.size() == 0) return StateMachineArtifact.DEFAULT_HOURS_PER_WORK_DAY;
return tasks.iterator().next().getManHrsPerDayPreference();
}
diff --git a/org.eclipse.osee.ats/src/org/eclipse/osee/ats/world/AtsMetricsComposite.java b/org.eclipse.osee.ats/src/org/eclipse/osee/ats/world/AtsMetricsComposite.java
index d357da058c9..7d06e41cbc2 100644
--- a/org.eclipse.osee.ats/src/org/eclipse/osee/ats/world/AtsMetricsComposite.java
+++ b/org.eclipse.osee.ats/src/org/eclipse/osee/ats/world/AtsMetricsComposite.java
@@ -222,7 +222,7 @@ public class AtsMetricsComposite extends ScrolledComposite {
lines.add(XBarGraphLine.getTextLine("Hours Spent: ", String.format("%5.2f Hours", sMet.getHrsSpent())));
lines.add(XBarGraphLine.getTextLine("Hours Per Man Day Preference: ", String.format("%5.2f Hours per Day",
sMet.getHoursPerManDay())));
- lines.add(XBarGraphLine.getTextLine("Man Days Needed: ", String.format(
+ lines.add(XBarGraphLine.getTextLine("Work Days Needed: ", String.format(
"%5.2f Days = Remaining Hours %5.2f / Hours Per Day of %5.2f", sMet.getManDaysNeeded(),
sMet.getHrsRemainFromEstimates(), sMet.getHoursPerManDay())));
diff --git a/org.eclipse.osee.ats/src/org/eclipse/osee/ats/world/WorldComposite.java b/org.eclipse.osee.ats/src/org/eclipse/osee/ats/world/WorldComposite.java
index c59eb982ed0..d908057594b 100644
--- a/org.eclipse.osee.ats/src/org/eclipse/osee/ats/world/WorldComposite.java
+++ b/org.eclipse.osee.ats/src/org/eclipse/osee/ats/world/WorldComposite.java
@@ -97,7 +97,7 @@ public class WorldComposite extends ScrolledComposite implements IOpenNewAtsWorl
}
return ((StateMachineArtifact) artifact).getManHrsPerDayPreference();
}
- return StateMachineArtifact.DEFAULT_MAN_HOURS_PER_DAY;
+ return StateMachineArtifact.DEFAULT_HOURS_PER_WORK_DAY;
}
public void setCustomizeData(CustomizeData customizeData) {
diff --git a/org.eclipse.osee.ats/src/org/eclipse/osee/ats/world/WorldLabelProvider.java b/org.eclipse.osee.ats/src/org/eclipse/osee/ats/world/WorldLabelProvider.java
index 4baf51cebcb..5a6bc58d92c 100644
--- a/org.eclipse.osee.ats/src/org/eclipse/osee/ats/world/WorldLabelProvider.java
+++ b/org.eclipse.osee.ats/src/org/eclipse/osee/ats/world/WorldLabelProvider.java
@@ -175,7 +175,7 @@ public class WorldLabelProvider extends XViewerLabelProvider {
if (result.isFalse()) return result.getText();
return AtsUtil.doubleToI18nString(wva.getWorldViewAnnualCostAvoidance(), true);
}
- if (xCol.equals(WorldXViewerFactory.Man_Days_Needed_Col)) {
+ if (xCol.equals(WorldXViewerFactory.Work_Days_Needed_Col)) {
Result result = wva.isWorldViewManDaysNeededValid();
if (result.isFalse()) return result.getText();
return AtsUtil.doubleToI18nString(wva.getWorldViewManDaysNeeded());
diff --git a/org.eclipse.osee.ats/src/org/eclipse/osee/ats/world/WorldXViewer.java b/org.eclipse.osee.ats/src/org/eclipse/osee/ats/world/WorldXViewer.java
index f134ab5ac17..6980c042854 100644
--- a/org.eclipse.osee.ats/src/org/eclipse/osee/ats/world/WorldXViewer.java
+++ b/org.eclipse.osee.ats/src/org/eclipse/osee/ats/world/WorldXViewer.java
@@ -594,6 +594,7 @@ public class WorldXViewer extends XViewer implements ISelectedAtsArtifacts, IArt
}
+ @Override
public void updateMenuActionsForTable() {
MenuManager mm = getMenuManager();
@@ -930,10 +931,10 @@ public class WorldXViewer extends XViewer implements ISelectedAtsArtifacts, IArt
AWorkbench.popup("Calculated Field",
"Hours Remaining field is calculated.\nHour Estimate - (Hour Estimate * Percent Complete)");
return false;
- } else if (xCol.equals(WorldXViewerFactory.Man_Days_Needed_Col)) {
+ } else if (xCol.equals(WorldXViewerFactory.Work_Days_Needed_Col)) {
AWorkbench.popup(
"Calculated Field",
- "Man Days Needed field is calculated.\nRemaining Hours / Hours per Week (" + smaMgr.getSma().getManHrsPerDayPreference() + ")");
+ "Work Days Needed field is calculated.\nRemaining Hours / Hours per Week (" + smaMgr.getSma().getManHrsPerDayPreference() + ")");
return false;
} else if (xCol.equals(WorldXViewerFactory.Release_Date_Col)) {
modified = smaMgr.promptChangeReleaseDate();
diff --git a/org.eclipse.osee.ats/src/org/eclipse/osee/ats/world/WorldXViewerFactory.java b/org.eclipse.osee.ats/src/org/eclipse/osee/ats/world/WorldXViewerFactory.java
index 180f8f43823..c6f1af56adc 100644
--- a/org.eclipse.osee.ats/src/org/eclipse/osee/ats/world/WorldXViewerFactory.java
+++ b/org.eclipse.osee.ats/src/org/eclipse/osee/ats/world/WorldXViewerFactory.java
@@ -206,8 +206,8 @@ public class WorldXViewerFactory extends SkynetXViewerFactory {
public static final XViewerColumn Cancelled_Date_Col =
new XViewerColumn(COLUMN_NAMESPACE + ".cancelledDate", "Cancelled Date", 80, SWT.CENTER, false,
SortDataType.Date, false, null);
- public static final XViewerColumn Man_Days_Needed_Col =
- new XViewerColumn(COLUMN_NAMESPACE + ".manDaysNeeded", "Man Days Needed", 40, SWT.CENTER, false,
+ public static final XViewerColumn Work_Days_Needed_Col =
+ new XViewerColumn(COLUMN_NAMESPACE + ".workDaysNeeded", "Hours Per Work Day", 40, SWT.CENTER, false,
SortDataType.Float, false, null);
public static final XViewerColumn Days_In_Current_State =
new XViewerColumn(COLUMN_NAMESPACE + ".daysInCurrState", "Days in Current State", 40, SWT.CENTER, false,
@@ -260,7 +260,7 @@ public class WorldXViewerFactory extends SkynetXViewerFactory {
Percent_Complete_State_Task_Col, Percent_Complete_State_Review_Col, Percent_Complete_Total_Col,
Hours_Spent_State_Col, Hours_Spent_State_Task_Col, Hours_Spent_State_Review_Col, Hours_Spent_Total_Col,
Total_Hours_Spent_Col, Originator_Col, Implementor_Col, Review_Author_Col, Review_Moderator_Col,
- Review_Reviewer_Col, Review_Decider_Col, Completed_Date_Col, Cancelled_Date_Col, Man_Days_Needed_Col,
+ Review_Reviewer_Col, Review_Decider_Col, Completed_Date_Col, Cancelled_Date_Col, Work_Days_Needed_Col,
Percent_Rework_Col, Branch_Status_Col, Number_of_Tasks_Col, Last_Modified_Col, Last_Statused_Col,
Validation_Required_Col, Review_Major_Defects, Review_Minor_Defects, Review_Issues,
Actions_Initiating_Workflow_Col, Artifact_Type_Col, Originating_Workflow, Parent_ID_Col,
diff --git a/org.eclipse.osee.ats/support/OseeTypes_ATS.osee b/org.eclipse.osee.ats/support/OseeTypes_ATS.osee
index fa23e43f2d0..b0af26316ec 100644
--- a/org.eclipse.osee.ats/support/OseeTypes_ATS.osee
+++ b/org.eclipse.osee.ats/support/OseeTypes_ATS.osee
@@ -1,5 +1,5 @@
-import "platform:/plugin/org.eclipse.osee.framework.skynet.core/support/OseeTypes_Framework.osee"
-
+import
+"platform:/plugin/org.eclipse.osee.framework.skynet.core/support/OseeTypes_Framework.osee"
abstract artifactType "ats.Release Artifact" extends "Artifact" {
guid "ABMZAdJpQi01iAbMBjgA"
attribute "ats.Released"
@@ -55,7 +55,7 @@ artifactType "Action" extends "ats.Ats Artifact" {
artifactType "Team Definition" extends "ats.Ats Artifact" {
guid "AAMFDhUrlytusKbaQGAA"
- attribute "ats.Man Days Needed"
+ attribute "ats.Hours Per Work Day"
attribute "ats.Full Name"
attribute "ats.Team Uses Versions"
attribute "ats.Require Targeted Version"
@@ -127,7 +127,7 @@ artifactType "Team Workflow" extends "Goal" {
attribute "ats.Actionable Item"
attribute "ats.Branch Id"
attribute "ats.Branch Metrics"
- attribute "ats.Baseline Branch Guid"
+ attribute "ats.Baseline Branch Guid"
attribute "ats.Transaction Id"
attribute "ats.Validation Required"
}
@@ -335,7 +335,7 @@ attributeType "ats.Weekly Benefit" extends FloatingPointAttribute {
defaultValue "0"
}
-attributeType "ats.Man Days Needed" extends FloatingPointAttribute {
+attributeType "ats.Hours Per Work Day" extends FloatingPointAttribute {
guid "AAMFEdGlqFsZp22RMdAA"
dataProvider DefaultAttributeDataProvider
min 0
@@ -392,7 +392,8 @@ attributeType "ats.Problem" extends StringAttribute {
dataProvider DefaultAttributeDataProvider
min 0
max 1
- taggerId DefaultAttributeTaggerProvider fileExtension "txt"
+ taggerId DefaultAttributeTaggerProvider
+ fileExtension "txt"
}
attributeType "ats.Proposed Resolution" extends StringAttribute {
@@ -408,7 +409,8 @@ attributeType "ats.Resolution" extends StringAttribute {
dataProvider DefaultAttributeDataProvider
min 0
max 1
- taggerId DefaultAttributeTaggerProvider fileExtension "txt"
+ taggerId DefaultAttributeTaggerProvider
+ fileExtension "txt"
}
attributeType "ats.Description" extends StringAttribute {
@@ -416,7 +418,8 @@ attributeType "ats.Description" extends StringAttribute {
dataProvider DefaultAttributeDataProvider
min 0
max 1
- taggerId DefaultAttributeTaggerProvider fileExtension "txt"
+ taggerId DefaultAttributeTaggerProvider
+ fileExtension "txt"
}
attributeType "ats.Full Name" extends StringAttribute {
@@ -446,14 +449,16 @@ attributeType "ats.Log" extends StringAttribute {
dataProvider DefaultAttributeDataProvider
min 0
max 1
- taggerId DefaultAttributeTaggerProvider fileExtension "xml"
+ taggerId DefaultAttributeTaggerProvider
+ fileExtension "xml"
}
attributeType "ats.State Notes" extends StringAttribute {
guid "AAMFEdiWPm7M_xV1EswA"
dataProvider DefaultAttributeDataProvider
min 0
- max 1 fileExtension "xml"
+ max 1
+ fileExtension "xml"
}
attributeType "ats.Related To State" extends StringAttribute {
@@ -538,7 +543,8 @@ attributeType "ats.Location" extends StringAttribute {
dataProvider DefaultAttributeDataProvider
min 0
max 1
- taggerId DefaultAttributeTaggerProvider fileExtension "txt"
+ taggerId DefaultAttributeTaggerProvider
+ fileExtension "txt"
}
attributeType "ats.Authors" extends StringAttribute {

Back to the top
diff --git a/org.eclipse.osee.ats/src/org/eclipse/osee/ats/artifact/TeamDefinitionArtifact.java b/org.eclipse.osee.ats/src/org/eclipse/osee/ats/artifact/TeamDefinitionArtifact.java
index 82415a13695..9dfaa6d0553 100644
--- a/org.eclipse.osee.ats/src/org/eclipse/osee/ats/artifact/TeamDefinitionArtifact.java
+++ b/org.eclipse.osee.ats/src/org/eclipse/osee/ats/artifact/TeamDefinitionArtifact.java
@@ -56,8 +56,7 @@ public class TeamDefinitionArtifact extends Artifact implements ICommitConfigArt
public static String ARTIFACT_NAME = "Team Definition";
public static Set<TeamDefinitionArtifact> EMPTY_SET = new HashSet<TeamDefinitionArtifact>();
public static enum TeamDefinitionOptions {
- TeamUsesVersions,
- RequireTargetedVersion
+ TeamUsesVersions, RequireTargetedVersion
};
/**
@@ -277,7 +276,7 @@ public class TeamDefinitionArtifact extends Artifact implements ICommitConfigArt
}
public double getManDayHrsFromItemAndChildren() {
- return getManDayHrsFromItemAndChildren(this);
+ return getHoursPerWorkDayFromItemAndChildren(this);
}
public WorkFlowDefinition getWorkFlowDefinition() throws OseeCoreException {
@@ -342,22 +341,19 @@ public class TeamDefinitionArtifact extends Artifact implements ICommitConfigArt
}
/**
* If man days hours attribute is set, use it, otherwise, walk up the Team Definition tree. Value used in
* calculations.
- *
- * @param teamDef
- * @return number of hours per single person per single day
*/
- public double getManDayHrsFromItemAndChildren(TeamDefinitionArtifact teamDef) {
+ public double getHoursPerWorkDayFromItemAndChildren(TeamDefinitionArtifact teamDef) {
try {
- Double manDaysHrs = teamDef.getSoleAttributeValue(ATSAttributes.MAN_DAYS_NEEDED_ATTRIBUTE.getStoreName(), 0.0);
+ Double manDaysHrs = teamDef.getSoleAttributeValue(ATSAttributes.HOURS_PER_WORK_DAY_ATTRIBUTE.getStoreName(), 0.0);
if (manDaysHrs != null && manDaysHrs != 0) {
return manDaysHrs;
}
if (teamDef.getParent() != null && teamDef.getParent() instanceof TeamDefinitionArtifact) {
- return teamDef.getManDayHrsFromItemAndChildren((TeamDefinitionArtifact) teamDef.getParent());
+ return teamDef.getHoursPerWorkDayFromItemAndChildren((TeamDefinitionArtifact) teamDef.getParent());
}
- return StateMachineArtifact.DEFAULT_MAN_HOURS_PER_DAY;
+ return StateMachineArtifact.DEFAULT_HOURS_PER_WORK_DAY;
} catch (Exception ex) {
OseeLog.log(AtsPlugin.class, Level.SEVERE, ex);
}
@@ -342,22 +341,19 @@ public class TeamDefinitionArtifact extends Artifact implements ICommitConfigArt
}
/**
- * If man days hours attribute is set, use it, otherwise, walk up the Team Definition tree. Value used in
+ * If hours per work day attribute is set, use it, otherwise, walk up the Team Definition tree. Value used in
* calculations.